@@ -89,9 +89,11 @@ def sql(key):
         'KAIAlertDisableId': {'sql':"SELECT id From KAIAlert Where status = 0 ;",'database': 'AnyRobot'},
         'ScheduleTaskEnableId': {'sql':"SELECT id From ScheduleTask Where status = 1 ;",'database': 'AnyRobot'},
         'ScheduleTaskDisableId': {'sql':"SELECT id From ScheduleTask Where status = 0 ;",'database': 'AnyRobot'},
-        'ReprotId': {'sql': "SELECT reprot_id From report ;", 'database': 'AnyRobot'},
+        'ReprotId': {'sql': "SELECT report_id From report WHERE is_share_allowed = 1;", 'database': 'AnyRobot'},
+        'ReprotIdDisable': {'sql': "SELECT report_id From report WHERE is_share_allowed = 0;", 'database': 'AnyRobot'},
         'ReprotName': {'sql': "SELECT `name` From report ;", 'database': 'AnyRobot'},
-        'ReprotType': {'sql': "SELECT `type` From report ;", 'database': 'AnyRobot'}
+        'ReprotType': {'sql': "SELECT `type` From report ;", 'database': 'AnyRobot'},
+
     }
 
     if switcher.get(key) is not None:
